<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">

<!--
SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.

SPDX-License-Identifier: LGPL-3.0-or-later
-->

<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1454"/>
        <source>%1 is released under %2</source>
        <translation>%1 está liberada baixo %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="869"/>
        <source>Black</source>
        <translation>Negro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="872"/>
        <source>White</source>
        <translation>Branco</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="875"/>
        <source>Dark Gray</source>
        <translation>Gris escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="878"/>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="881"/>
        <source>Light Gray</source>
        <translation>Gris claro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="884"/>
        <source>Red</source>
        <translation>Vermello</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="887"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="890"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="893"/>
        <source>Cyan</source>
        <translation>Ciano</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="896"/>
        <source>Magenta</source>
        <translation>Maxenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="899"/>
        <source>Yellow</source>
        <translation>Amarelo</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="902"/>
        <source>Dark Red</source>
        <translation>Vermello escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="905"/>
        <source>Dark Green</source>
        <translation>Verde escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="908"/>
        <source>Dark Blue</source>
        <translation>Azul escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="911"/>
        <source>Dark Cyan</source>
        <translation>Ciano escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="914"/>
        <source>Dark Magenta</source>
        <translation>Maxenta escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="917"/>
        <source>Dark Yellow</source>
        <translation>Amarelo escuro</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="30"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="97"/>
        <source>Enter a new shortcut</source>
        <translation>Inserir atallo novo</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="593"/>
        <source>Stop reading</source>
        <translation>Parar de ler</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="595"/>
        <source>Text to Speech</source>
        <translation>De texto a voz</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="618"/>
        <source>Translate</source>
        <translation>Traducir</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="640"/>
        <source>Speech To Text</source>
        <translation>Da voz ao texto</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="278"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1268"/>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="302"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1647"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="318"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="334"/>
        <source>Printer</source>
        <translation>Impresora</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="350"/>
        <source>Copies</source>
        <translation>Copias</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="372"/>
        <source>Page range</source>
        <translation>Rangos de páxina</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="375"/>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="376"/>
        <source>Current page</source>
        <translation>Páxina actual</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
        <source>Select pages</source>
        <translation>Seleccionar páxinas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="397"/>
        <source>Orientation</source>
        <translation>Orientación</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="422"/>
        <source>Portrait</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="432"/>
        <source>Landscape</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="460"/>
        <source>Pages</source>
        <translation>Páxinas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="472"/>
        <source>Color mode</source>
        <translation>Modo de cor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1583"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1663"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1679"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1694"/>
        <source>Color</source>
        <translation type="vanished">Cor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1670"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1682"/>
        <source>Grayscale</source>
        <translation>Escala de grises</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
        <source>Margins</source>
        <translation>Marxes</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Narrow (mm)</source>
        <translation>Estreito (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Normal (mm)</source>
        <translation>Normal (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Moderate (mm)</source>
        <translation>Moderado (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Customize (mm)</source>
        <translation>Personalizar (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="500"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="503"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="506"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="509"/>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="556"/>
        <source>Scaling</source>
        <translation>Escalado</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="573"/>
        <source>Actual size</source>
        <translation>Tamaño actual</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="582"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="613"/>
        <source>Paper</source>
        <translation>Papel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="626"/>
        <source>Paper size</source>
        <translation>Tamaño do papel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="641"/>
        <source>Print Layout</source>
        <translation>Deseño de impresión</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
        <source>Duplex</source>
        <translation>Dúplex</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="668"/>
        <source>N-up printing</source>
        <translation>Impresión de varias páxinas por folla</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 páxinas/folla, 1×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 páxinas/folla, 2×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 páxinas/folla, 2×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 páxinas/folla, 3×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 páxinas/folla, 4×4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="683"/>
        <source>Layout direction</source>
        <translation>Dirección de deseño</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="727"/>
        <source>Page Order</source>
        <translation>Orde de páxina</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
        <source>Collate pages</source>
        <translation>Recolle páxinas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="746"/>
        <source>Print pages in order</source>
        <translation>Imprimir páxinas en orde</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Front to back</source>
        <translation>Fronte a atrás</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Back to front</source>
        <translation>De atrás á fronte</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="774"/>
        <source>Watermark</source>
        <translation>Marca de auga</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="788"/>
        <source>Add watermark</source>
        <translation>Engadir marca de auga</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="834"/>
        <source>Text watermark</source>
        <translation>Texto da marca de auga</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Confidential</source>
        <translation>Confidencial</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Draft</source>
        <translation>Borrador</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Sample</source>
        <translation>Exemplo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Custom</source>
        <translation>Personalizar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
        <source>Input your text</source>
        <translation>Introduce o teu texto</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="872"/>
        <source>Picture watermark</source>
        <translation>Imaxe da marca de auga</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="896"/>
        <source>Layout</source>
        <translation>Deseño</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Tile</source>
        <translation>Mosaico</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="912"/>
        <source>Angle</source>
        <translation>Ángulo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="931"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="955"/>
        <source>Transparency</source>
        <translation>Transparencia</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1013"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2283"/>
        <source>Print to PDF</source>
        <translation>Imprimir en PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1014"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2282"/>
        <source>Save as Image</source>
        <translation>Gardar como Imaxe</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1264"/>
        <source>Collapse</source>
        <translation>Colapsar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1359"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1368"/>
        <source>Flip on short edge</source>
        <translation>Xirar no borde curto</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1298"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1363"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1367"/>
        <source>Flip on long edge</source>
        <translation>Xirar no borde longo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1461"/>
        <source>Input page numbers please</source>
        <translation>Introduza os números de páxinas, por favor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1464"/>
        <source>Maximum page number reached</source>
        <translation>Alcanzouse o número máximo de páxinas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1467"/>
        <source>Input English comma please</source>
        <translation>Introduza a coma inglesa, por favor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1470"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Introduza os números de páxina como segue: 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1700"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Gardar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>*.pdf</source>
        <translation>*.pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1770"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Por exemplo, 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>Save as PDF</source>
        <translation>Gardar como PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2351"/>
        <source>Save as image</source>
        <translation>Gardar como imaxe</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2353"/>
        <source>Images</source>
        <translation>Imaxes</translation>
    </message>
    <message>
        <source>Full Color</source>
        <translation>Toda cor</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
        <source>Confidential</source>
        <translation>Confidencial</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
        <source>Draft</source>
        <translation>Borrador</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
        <source>Sample</source>
        <translation>Exemplo</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="286"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="66"/>
        <source>Replace</source>
        <translation>Substituír</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="68"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Este atallo entra en conflito con 1%, prema en Engadir para facer efectivo este atallo inmediatamente</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="18"/>
        <source>Please input a new shortcut</source>
        <translation>Por favor, inserte un novo atallo</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="89"/>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="202"/>
        <source>Stop reading</source>
        <translation>Parar de ler</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="204"/>
        <source>Text to Speech</source>
        <translation>De texto a voz</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="227"/>
        <source>Translate</source>
        <translation>Traducir</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="249"/>
        <source>Speech To Text</source>
        <translation>Da voz ao texto</translation>
    </message>
</context>
<context>
    <name>DToolbarEditPanel</name>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="884"/>
        <source>Default toolset</source>
        <translation>Conxunto de ferramentas predeterminado</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="915"/>
        <source>Drag your favorite items into the toolbar</source>
        <translation>Arrastra os teus elementos favoritos á barra de ferramentas</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="916"/>
        <source>Drag below items into the toolbar to restore defaults</source>
        <translation>Arrastra os elementos de abaixo á barra de ferramentas para restaurar os valores predeterminados</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="921"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="94"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="526"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="529"/>
        <source>Cu&amp;t</source>
        <translation>Pegar&amp;</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="534"/>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1347"/>
        <source>No search result</source>
        <translation>Sen resultados</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="330"/>
        <source>Restore Defaults</source>
        <translation>Restaurar predefinidos</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="108"/>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="110"/>
        <source>Features</source>
        <translation>Características</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="122"/>
        <source>Homepage</source>
        <translation>Páxina de inicio</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="124"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="126"/>
        <source>Acknowledgements</source>
        <translation>Recoñecementos</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="128"/>
        <location filename="../widgets/daboutdialog.cpp" line="393"/>
        <source>Sincerely appreciate the open-source software used.</source>
        <translation>Agradecemos sinceramente o software de código aberto utilizado.</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="395"/>
        <source>open-source software</source>
        <translation>software de código aberto</translation>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="151"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="175"/>
        <source>Learn More</source>
        <translation>Saber máis</translation>
    </message>
    <message>
        <location filename="../widgets/dlicensedialog.cpp" line="78"/>
        <source>Open-Source Software</source>
        <translation>Software de código aberto</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="194"/>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="104"/>
        <source>Please enter a new shortcut</source>
        <translation>Por favor, insire un novo atallo</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="634"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="636"/>
        <source>Light Theme</source>
        <translation>Tema claro</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="637"/>
        <source>Dark Theme</source>
        <translation>Tema escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="638"/>
        <source>System Theme</source>
        <translation>Tema do sistema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="668"/>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="676"/>
        <source>Feedback</source>
        <translation>Retroalimentar</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="683"/>
        <source>Custom toolbar</source>
        <translation>Barra de ferramentas personalizada</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="691"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="698"/>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
</context>
</TS>